@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from contextlib import contextmanager
-from typing import TYPE_CHECKING, Callable, Generator
+from typing import TYPE_CHECKING, Callable
 
 from nextline.process.trace.wrap import WithContext
 
@@ -19,7 +19,7 @@ def PdbInterfaceTraceFuncFactory(context: TraceContext) -> Callable[[], TraceFun
 
         callback = context['callback']
         callback.task_or_thread_start()
-        trace = PdbInterface(context=context)
+        trace = instantiate_pdb(context=context)
 
         trace = TraceCallCallback(trace=trace, context=context)
         # TODO: Add a test. The tests pass without the above line.  Without it,
@@ -41,53 +41,15 @@ def TraceCallCallback(trace: TraceFunc, context: TraceContext) -> TraceFunc:
     return WithContext(trace, context=_context)
 
 
-def PdbInterface(context: TraceContext):
-    '''
-      pdb.trace_dispatch()
-       |
-       |--> pdb._cmdloop()
-             |
-             | with
-             |--> interface_cmdloop()
-                   |
-                   | with
-                   |--> callback.cmdloop()
-                         |
-                   |<----| yield
-             |<----| yield
-             |
-             |-------------> pdb.cmdloop()
-                               |
-                               V
-             |<-----------------
-             |
-             |---->| exit
-                   |---->| exit
-                         V
-                   |<-----
-                   V
-             |<-----
-             V
-       |<-----
-       V
+def instantiate_pdb(context: TraceContext):
+    '''Create a new Pdb instance with callback hooked and return its trace function.'''
 
-    '''
-
-    cmdloop_interface = CmdLoopInterface(context=context)
-
-    @contextmanager
-    def interface_cmdloop() -> Generator[None, None, None]:
-        '''To be called in CustomizedPdb._cmdloop()'''
-
-        with context['callback'].cmdloop():
-            yield
+    cmdloop_interface = CmdLoopInterface(prompt_func=context['callback'].prompt)
 
     pdb = CustomizedPdb(
-        interface_cmdloop=interface_cmdloop,
+        cmdloop_hook=context['callback'].cmdloop,
         stdin=cmdloop_interface.stdin,
         stdout=cmdloop_interface.stdout,
-        nosigint=True,
-        readrc=False,
     )
     cmdloop_interface.prompt_end = pdb.prompt
 
